========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/python-glanceclient.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html
    :alt: The following tags have been asserted for Python bindings to the
          OpenStack Images API:
          "project:official",
          "stable:follows-policy",
          "vulnerability:managed".
          Follow the link for an explanation of these tags.
.. NOTE(rosmaita): the alt text above will have to be updated when
   additional tags are asserted for python-glanceclient.  (The SVG in the
   governance repo is updated automatically.)

.. Change things from this point on

===========================================
Python bindings to the OpenStack Images API
===========================================

.. image:: https://img.shields.io/pypi/v/python-glanceclient.svg
    :target: https://pypi.org/project/python-glanceclient/
    :alt: Latest Version

This is a client library for Glance built on the OpenStack Images API. It provides a Python API (the ``glanceclient`` module) and a command-line tool (``glance``). This library fully supports the v1 Images API, while support for the v2 API is in progress.

Development takes place via the usual OpenStack processes as outlined in the `developer guide <https://docs.openstack.org/infra/manual/developers.html>`_.  The master repository is in `Git <https://opendev.org/openstack/python-glanceclient>`_.

See release notes and more at `<https://docs.openstack.org/python-glanceclient/latest/>`_.

* License: Apache License, Version 2.0
* `PyPi`_ - package installation
* `Online Documentation`_
* `Launchpad project`_ - release management
* `Blueprints`_ - feature specifications
* `Bugs`_ - issue tracking
* `Source`_
* `Specs`_
* `How to Contribute`_

.. _PyPi: https://pypi.org/project/python-glanceclient
.. _Online Documentation: https://docs.openstack.org/python-glanceclient/latest/
.. _Launchpad project: https://launchpad.net/python-glanceclient
.. _Blueprints: https://blueprints.launchpad.net/python-glanceclient
.. _Bugs: https://bugs.launchpad.net/python-glanceclient
.. _Source: https://opendev.org/openstack/python-glanceclient
.. _How to Contribute: https://docs.openstack.org/infra/manual/developers.html
.. _Specs: https://specs.openstack.org/openstack/glance-specs/
.. _Release notes: https://docs.openstack.org/releasenotes/python-glanceclient
